# $Id: Settings.pm 1715 2011-02-03 21:54:14Z mats $

package Plugins::squeezedVera::Settings;

# SqueezeCenter Copyright 2001-2007 Logitech.
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License,
# version 2.

# Settings file.
# This file contains stuff generally applicable to the web interface used to set
# the settings for the plugin.

# All good/required uses to have in here.
use strict;
use base qw(Slim::Web::Settings);
use Slim::Utils::Prefs;
use Slim::Utils::Log;

# This gets the current preferences stored for the plugin.
# This call to "preferences" returns a pointer to that data that can then be read or set.
my $prefs = preferences('plugin.squeezedvera');

sub name {
    return Slim::Web::HTTP::CSRF->protectName('PLUGIN_SQUEEZED_VERA');
}

# Points to basic.html that is in some funky HTML-like format that is used to display the
# settings page when you select
# "Settings->Extras->[plugin's settings box]" from the SC7 window.
sub page {
    return Slim::Web::HTTP::CSRF->protectURI('plugins/squeezedVera/settings/basic.html');
}

# Required function used to process the web page input.
# This handler is called whenever the webpage is displayed as well as when a setting is "applied."
sub handler {
	my ($class, $client, $params) = @_;

	# When "apply" is pressed on the settings page, this function gets called.
	# So, double check that the apply button was pressed and if so, set that
        # value into the prefs variable
	if ($params->{'saveSettings'}) {
            my $script_path = $params->{'script_path'};
            $prefs->set('script_path', "$script_path"); 
	}
        
        if ($params->{'saveSettings'}) {
            my $demand_scripts = $params->{'demand_scripts'};
            $prefs->set('demand_scripts', "$demand_scripts"); 
	}
        
        if ($params->{'saveSettings'}) {
            my $pwr_on_scripts = $params->{'pwr_on_scripts'};
            $prefs->set('pwr_on_scripts', "$pwr_on_scripts"); 
	}

        if ($params->{'saveSettings'}) {
            my $pwr_off_scripts = $params->{'pwr_off_scripts'};
            $prefs->set('pwr_off_scripts', "$pwr_off_scripts"); 
	}

        if ($params->{'saveSettings'}) {
            my $play_scripts = $params->{'play_scripts'};
            $prefs->set('play_scripts', "$play_scripts"); 
	}

        if ($params->{'saveSettings'}) {
            my $alarm_timeout_scripts = $params->{'alarm_timeout_scripts'};
            $prefs->set('alarm_timeout_scripts', "$alarm_timeout_scripts"); 
	}

        if ($params->{'saveSettings'}) {
            my $alarm_scripts = $params->{'alarm_scripts'};
            $prefs->set('alarm_scripts', "$alarm_scripts"); 
	}

        if ($params->{'saveSettings'}) {
            my $sqvs_path = $params->{'sqvs_path'};
            $prefs->set('sqvs_path', "$sqvs_path"); 
	}

        if ($params->{'saveSettings'}) {
            my $sqvs_timer = $params->{'sqvs_timer'};
            $prefs->set('sqvs_timer', "$sqvs_timer"); 
	}
        

	# This puts the value on the webpage. 
	# If the page is just being displayed initially, then this puts the current value
        # found in prefs on the page.
	$params->{'prefs'}->{'script_path'} = $prefs->get('script_path');
        $params->{'prefs'}->{'demand_scripts'} = $prefs->get('demand_scripts');
        $params->{'prefs'}->{'pwr_on_scripts'} = $prefs->get('pwr_on_scripts');
        $params->{'prefs'}->{'pwr_off_scripts'} = $prefs->get('pwr_off_scripts');
        $params->{'prefs'}->{'play_scripts'} = $prefs->get('play_scripts');
        $params->{'prefs'}->{'alarm_timeout_scripts'} = $prefs->get('alarm_timeout_scripts');
        $params->{'prefs'}->{'alarm_scripts'} = $prefs->get('alarm_scripts');
        $params->{'prefs'}->{'sqvs_path'} = $prefs->get('sqvs_path');
        $params->{'prefs'}->{'sqvs_timer'} = $prefs->get('sqvs_timer');

	# I have no idea what this does, but it seems important and it's not plugin-specific.
	return $class->SUPER::handler($client, $params);
}

1;

__END__
